@@ -245,6 +245,18 @@ def _write_csv(input_files, results, csv_path=None):
 
 
 @main.command()
+@click.option(
+    "--yara-repo",
+    type=click.Path(file_okay=False),
+    help="Directory containing YARA signatures used for auto detection.",
+)
+@click.option(
+    "--recursive/--no-recursive",
+    default=True,
+    show_default=True,
+    help="Whether to recursively parse unidentified residual files using YARA match. "
+         "(Only works if a YARA repo has been provided through command line or configuration)"
+)
 @click.option(
     "-f", "--format",
     type=click.Choice(["csv", "json", "simple", "markdown", "html", "stix"]),
@@ -272,12 +284,6 @@ def _write_csv(input_files, results, csv_path=None):
     show_default=True,
     help="Whether to output files to filesystem."
 )
-@click.option(
-    "--cleanup/--no-cleanup",
-    default=True,
-    show_default=True,
-    help="Whether to cleanup temporary files after parsing."
-)
 @click.option(
     "--prefix/--no-prefix",
     default=True,
@@ -307,12 +313,12 @@ def _write_csv(input_files, results, csv_path=None):
 )
 @click.argument("parser", required=True)
 @click.argument("input", nargs=-1, type=click.Path())
-def parse(parser, input, format, split, output_dir, output_files, cleanup, prefix, string_report, include_filename, legacy):
+def parse(parser, input, yara_repo, recursive, format, split, output_dir, output_files, prefix, string_report, include_filename, legacy):
     """
     Parses given input with given parser.
 
     \b
-    PARSER: Name of parser to run.
+    PARSER: Name of parser to run. (or "-" for YARA matching)
     INPUT: One or more input file paths. (Wildcards are allowed).
 
     \b
@@ -321,7 +327,12 @@ def parse(parser, input, format, split, output_dir, output_files, cleanup, prefi
         mwcp parse foo ./repo/*                               - Run foo parser on files found in repo directory.
         mwcp parse -f json foo ./malware.bin                  - Run foo parser and display results as json.
         mwcp parse -f csv foo ./repo/* > ./results.csv        - Run foo parser on a directory and output results as a csv file.
+        mwcp parse - ./malware.bin --yara-repo=./rules        - Run a parser on ./malware.bin where the parser is detected by YARA.
+        mwcp parse - ./malware.bin                            - yara_repo can be omitted if included in configuration.
     """
+    if yara_repo:
+        mwcp.config["YARA_REPO"] = yara_repo
+
     # Python won't process wildcards when used through Windows command prompt.
     if any("*" in path for path in input):
         new_input = []
@@ -339,20 +350,20 @@ def parse(parser, input, format, split, output_dir, output_files, cleanup, prefi
     try:
         reports = []
         for path in input_files:
-            runner = mwcp.Runner(
-                # Store output files to a folder with the same name as the input file.
-                output_directory=os.path.join(output_dir, os.path.basename(path) + "_mwcp_output")
-                    if output_files else None,
-                cleanup_temp_files=cleanup,
+            config = dict(
+                output_directory=os.path.join(output_dir, os.path.basename(path) + "_mwcp_output") if output_files else None,
                 prefix_output_files=prefix,
                 external_strings_report=string_report,
+                recursive=recursive,
             )
+            if parser == "-":
+                parser = None
             logger.info("Parsing: {}".format(path))
             # TODO: This is temporary, make real fix.
             if path == "-":
-                report = runner.run(parser, data=sys.stdin.read().encode())
+                report = mwcp.run(parser, data=sys.stdin.read().encode(), **config)
             else:
-                report = runner.run(parser, path)
+                report = mwcp.run(parser, file_path=path, **config)
             reports.append(report)
 
         # TODO: Perhaps split up results with header of input file?
@@ -616,11 +627,25 @@ def _run_tests(tester, silent=False, show_passed=False):
     is_flag=True,
     help="Whether to display a full diff for failed tests. Disables custom unified diff display."
 )
+@click.option(
+    "--yara-repo",
+    type=click.Path(file_okay=False),
+    help="Directory containing YARA signatures used for auto detection.",
+)
+@click.option(
+    "--recursive/--no-recursive",
+    default=None,
+    show_default=True,
+    help="Whether to recursively parse unidentified residual files using YARA match. "
+         "When updating tests, this will force all tests to be either recursive or non-recursive. "
+         "Do not set if you would like to use what is currently set in the test case. "
+         "(Only works if a YARA repo has been provided through command line or configuration). "
+)
 # Parser to process.
 @click.argument("parser", nargs=-1, required=False)
 def test(
     testcase_dir, malware_repo, nprocs, update, add, add_filelist, delete, yes, force, last_failed, show_passed,
-    silent, legacy, exit_on_first, command, full_diff, parser,
+    silent, legacy, exit_on_first, command, full_diff, yara_repo, recursive, parser,
 ):
     """
     Testing utility to create and execute parser test cases.
@@ -633,10 +658,12 @@ def test(
         mwcp test                                             - Run all tests cases.
         mwcp test foo                                         - Run test cases for foo parser.
         mwcp test foo -u                                      - Update existing test cases for foo parser.
+        mwcp test foo -u --recursive                          - Update existing test cases for foo parser with recursive YARA matching for unidentified files.
         mwcp test -u                                          - Update existing test cases for all parsers.
         mwcp test --lf                                        - Rerun previously failed test cases.
         mwcp test --lf -u                                     - Update test cases that previously failed.
         mwcp test foo --add=./malware.bin                     - Add test case for malware.bin sample for foo parser.
+        mwcp test foo --add=./malware.bin --recursive         - Add test case for malware.bin sample for foo parser with recursive YARA matching for unidentified files.
         mwcp test foo -u --add=./malware.bin                  - Add test case for malware.bin sample.
                                                                 Allow updating if a test case for this file already exists.
         mwcp test foo --add-filelist=./paths.txt              - Add tests cases for foo parser using text file of paths.
@@ -647,6 +674,8 @@ def test(
         mwcp.config["TESTCASE_DIR"] = testcase_dir
     if malware_repo:
         mwcp.config["MALWARE_REPO"] = malware_repo
+    if yara_repo:
+        mwcp.config["YARA_REPO"] = yara_repo
 
     # Add files listed in filelist to add option.
     if add_filelist:
@@ -677,7 +706,7 @@ def test(
                 tester.remove_test(file_path)
         else:
             for file_path in add:
-                testing.add_tests(file_path, parsers=parser, force=force, update=update)
+                testing.add_tests(file_path, parsers=parser, force=force, update=update, recursive=recursive or False)
 
             for file_path in delete:
                 testing.remove_tests(file_path, parsers=parser)
@@ -699,7 +728,7 @@ def test(
                 test_cases = testing.iter_test_cases(parsers=parser)
             for test_case in test_cases:
                 click.secho(f"Updating {test_case.name}-{test_case.md5}...", fg="green")
-                test_case.update(force=force)
+                test_case.update(force=force, recursive=recursive)
 
     # Run tests
     else:
@@ -716,6 +745,14 @@ def test(
 
         # Run pytest with "parsers" marker to run parsing tests.
         else:
+            # If user set the `--recursive` flag, warn them that this is ignored.
+            if recursive:
+                logger.warning(
+                    "'--recursive' flag is ignored when running tests. "
+                    "Recursion is determined by the test case file itself. "
+                    "Update the test case with '--recursive' and '-u' if you want recursion for this test."
+                )
+
             # Due to bug in pytest, we won't get our custom command line arguments
             # registered just by using "--pyargs mwcp".
             # Therefore, we need to explicitly define the full path.
